# Instmuse

This package is a set of tools designed to work with physical instruments, it uses numuse's notation.

To get started visit the [documentation](https://instmuse.readthedocs.io/en/latest/).

If you're able to find use in this project, then please consider [contributing](https://www.patreon.com/cuppajoeman).
